==> moodle-1.5-mysql.tgz: moodle/lang/th/lesson.php <==
<?PHP // $Id$ 
      // lesson.php - created with Moodle 1.6 development (2005052400)


$string['actionaftercorrectanswer'] = '͵ͺӶ١';
$string['addabranchtable'] = 'úҭ';
$string['addanendofbranch'] = '˹ҨǢ';
$string['addaquestionpage'] = '˹ҤӶ';
$string['addcluster'] = '';
$string['addendofcluster'] = '˹Ҩͧ';
$string['answer'] = '͡';
$string['answeredcorrectly'] = 'ͺ١ͧ';
$string['answersfornumerical'] = 'ӵͺ繵ŢҧҵشФ٧ش';
$string['arrangebuttonshorizontally'] = 'ѴҢǹ͹ʴŴ';
$string['attempt'] = '駷 : $a';
$string['attempts'] = '';
$string['available'] = '';
$string['averagescore'] = 'ṹ';
$string['averagetime'] = '';
$string['backtreeview'] = 'Ѻѧ˹ͧѹ';
$string['branchtable'] = 'úҭ';
$string['cancel'] = '¡ԡ';
$string['canretake'] = '$a ö¹';
$string['casesensitive'] = 'Ǿ˭еǾ硶繤е';
$string['checkbranchtable'] = 'Ǩͺúҭ';
$string['checkedthisone'] = 'Ǩͺ˹ҹ';
$string['checknavigation'] = 'Ǩͺԧ';
$string['checkquestion'] = 'ǨͺӶ';
$string['classstats'] = 'ʶԵ';
$string['clicktopost'] = 'ԡ͡͡ṹͧسŧ¡äṹ٧ش';
$string['clusterjump'] = 'Ӷʴ㹺';
$string['clustertitle'] = '';
$string['comments'] = 'Դ';
$string['commentswithname'] = 'Դ繢ͧ $a->firstname {$a->lastname}';
$string['completed'] = '';
$string['confirmdeletionofthispage'] = '׹ѹź˹ҹ';
$string['congratulations'] = 'Թմ¤  س֡Ҩ¹';
$string['continue'] = '';
$string['continuetoanswer'] = '¹ӵͺ';
$string['correctanswerjump'] = 'ӵͺ١';
$string['correctanswerscore'] = 'ṹ';
$string['correctresponse'] = 'ӵͺ١';
$string['customscoring'] = 'Ѻ¹ṹ';
$string['deadline'] = 'ࢵ';
$string['deleteattempts'] = 'źѹ֡÷Ӻ¹ٻѡ¹·';
$string['deleting'] = 'ѧź';
$string['deletingpage'] = 'ź˹ $a';
$string['description'] = '͸Ժ';
$string['detailedstats'] = 'ʶԵ';
$string['didnotanswerquestion'] = 'ѧͺӶ';
$string['didnotreceivecredit'] = 'ôԵ';
$string['displayhighscores'] = 'ʴṹ٧ش';
$string['displayinleftmenu'] = 'ʴ٫';
$string['displayleftmenu'] = 'ʴ٫';
$string['displayofgrade'] = 'ʴṹ (Ѻѡ¹)';
$string['displayreview'] = 'ʴʴ';
$string['displayscorewithessays'] = 'ṹ $a->score ҡ $a->tempmaxgrade ѺӶṹѵѵ<br />$a->essayquestions 繤§աõǨṹѧ<br />кйӤṹѧѺṹѨغѹ<br /><br />ṹ͹Ӷ繤§ $a->score ҡ $a->grade';
$string['displayscorewithoutessays'] = 'ṹ $a->score (ҡṹ $a->grade).';
$string['editlessonsettings'] = '䢡õ駤Һ¹ٻ';
$string['editpagecontent'] = '˹ҹ';
$string['email'] = '';
$string['emailallgradedessays'] = 'ŷء <br />ṹ§';
$string['emailgradedessays'] = 'Ťṹҡ§';
$string['emailsuccess'] = 'º';
$string['endofbranch'] = 'Ǣ';
$string['endofclustertitle'] = '';
$string['endoflesson'] = '¹ٻ';
$string['enteredthis'] = 'ç';
$string['entername'] = 'Ѻ¡äṹ٧ش';
$string['enterpassword'] = 'سʼҹ';
$string['eolstudentoutoftime'] = '͹  㹡÷Ӻ¹ٻǤӵͺѧҡҹդṹ';
$string['eolstudentoutoftimenoanswers'] = 'سѧͺӶṹ 0 Ѻ¹ٻ';
$string['essay'] = '§';
$string['essayemailsubject'] = 'ṹѺ $a Ӷ';
$string['essays'] = '§';
$string['essayscore'] = 'ṹ§';
$string['fileformat'] = 'ٻẺͧ';
$string['firstanswershould'] = 'ӵͺáѧ˹ҷͺ١';
$string['firstwrong'] = 'سṹѺ͹еͺӶ١ͧ سͧ÷Ҥӵͺ  ͤʹءʹҹ (ṹФ)';
$string['gobacktolesson'] = 'Ѻѧ¹ٻ';
$string['grade'] = 'ṹ';
$string['gradeessay'] = 'ṹӶ§';
$string['gradeis'] = 'ṹ $a ';
$string['handlingofretakes'] = 'äԴṹ¹';
$string['havenotgradedyet'] = 'ѧṹ';
$string['here'] = 'ç';
$string['highscore'] = 'ṹ٧ش';
$string['hightime'] = 'ҡش';
$string['importquestions'] = 'ҤӶ';
$string['jump'] = '';
$string['jumptsto'] = 'ѧ..';
$string['leftduringtimed'] = 'س͡ҡ÷Ӻ¹ٻ͹Ҩ سҤԡ \"\" ͷӺ¹ٻ';
$string['leftduringtimednoretake'] = 'س͡ҡ÷Ӻ¹ٻѺ͹حҵӺ¹ٻͷӺ¹ٻ';
$string['lesson'] = '$a ¹ٻ';
$string['lessonclosed'] = 'ҷӺ¹ٻ $a';
$string['lessondefault'] = 'ҷѺ¹繤ѧ';
$string['lessonmenu'] = 'ٺ¹';
$string['lessonopen'] = 'ԴӺ¹ $a';
$string['lessonstats'] = 'ʶԵ';
$string['loginfail'] = 'к سͧա駤';
$string['lowscore'] = 'ṹش';
$string['lowtime'] = 'ҹش';
$string['mainmenu'] = 'ѡ';
$string['matchesanswer'] = 'Ѻӵͺ';
$string['maxhighscores'] = 'ӹǹṹ٧شͧʴ';
$string['maximumnumberofanswersbranches'] = 'ӹǹӵͺ/ҧ͡٧ش';
$string['maximumnumberofattempts'] = 'ӹǹ駷ͺ٧ش';
$string['maxtime'] = 'ҷ(ҷ)';
$string['maxtimewarning'] = 'س $a ҷ㹡÷Ӻ¹';
$string['minimumnumberofquestions'] = 'ӹǹӶش';
$string['modattempts'] = '͹حҵѡ¹ʴԴ';
$string['modattemptsnoteacher'] = 'ѡ¹ö੾ЧҹѺѡ¹';
$string['modulename'] = '¹ٻ';
$string['modulenameplural'] = '¹ٻ';
$string['movepagehere'] = 'ҷ';
$string['moving'] = '˹ $a';
$string['movingtonextpage'] = 'ѧӷҹ˹ҶѴ';
$string['multianswer'] = '¤ӵͺ';
$string['multipleanswer'] = 'ӵͺҡ˹';
$string['nameapproved'] = '͹حҵ';
$string['namereject'] = '¤Фسö͹س¹';
$string['nextpage'] = '˹ҵ';
$string['noanswer'] = 'դӵͺ';
$string['noattemptrecordsfound'] = '辺ѹ֡֡ ѧդṹ';
$string['nocommentyet'] = 'ѧբʹ';
$string['nohighscores'] = 'ѧդṹ٧';
$string['nooneansweredcorrectly'] = 'ѧõͺӶ١';
$string['nooneansweredthisquestion'] = 'ѧõͺӶ͹';
$string['noonecheckedthis'] = 'ѧ礢͹';
$string['nooneenteredthis'] = 'ѧҵç';
$string['noretake'] = 'سöӺ¹ٻ';
$string['normal'] = ' :: ¹¹ҧ';
$string['notcompleted'] = 'ѧó';
$string['notdefined'] = '˹';
$string['nothighscore'] = 'س $a ѹѺṹ٧ش';
$string['notitle'] = 'ժ';
$string['numberofcorrectanswers'] = 'ͺ١  $a ';
$string['numberofcorrectmatches'] = 'Ѻ١  $a ';
$string['numberofpagestoshow'] = 'ӹǹ˹ҷͧʴ';
$string['numberofpagesviewed'] = 'Ҫ  $a  ˹';
$string['ongoing'] = 'ʴṹҧӺ¹';
$string['ongoingcustom'] = '¹դṹ $a->grade ṹ ṹس $a->score ṹҡ $a->currenthigh ṹ';
$string['ongoingnormal'] = 'سͺӶ١ͧ $a->correct ͨҡ $a->viewed ';
$string['or'] = '';
$string['ordered'] = 'Ѵ§';
$string['outof'] = 'ҡ $a';
$string['outoftime'] = '';
$string['overview'] = 'Ҿ';
$string['page'] = '˹ $a ';
$string['pagecontents'] = '';
$string['pages'] = '˹';
$string['pagetitle'] = 'Ǣ';
$string['password'] = 'ʼҹ';
$string['passwordprotectedlesson'] = '¹$a ͧʼҹ㹡价';
$string['pleasecheckoneanswer'] = 'Ǩӵͺ';
$string['pleasecheckoneormoreanswers'] = 'Ǩӵͺ';
$string['pleaseenteryouranswerinthebox'] = 'سӵͺ㹪ͧҧ';
$string['pleasematchtheabovepairs'] = 'Ѻʹҹ';
$string['pointsearned'] = 'ṹ';
$string['postsuccess'] = 'ʵ';
$string['practice'] = 'ͧӺ¹ٻ';
$string['previouspage'] = '˹ҡ͹';
$string['question'] = 'Ӷ';
$string['questionoption'] = '礷ѺӶ¤ӵͺ/ ͧк¡Ǿ˭繤е';
$string['questiontype'] = 'ͧӶ';
$string['randombranch'] = '˹Ǣͷ';
$string['randompageinbranch'] = 'ӶǢ';
$string['rank'] = 'ѹѹ';
$string['reached'] = '֧';
$string['receivedcredit'] = 'ѺôԵ';
$string['redisplaypage'] = 'ʴ';
$string['report'] = '§ҹ';
$string['response'] = '͵ͺ͹ʴͤ..';
$string['returnmainmenu'] = 'Ѻѧѡ';
$string['returntocourse'] = 'ѺѧԪ';
$string['reviewlesson'] = 'ǡѺ¹ٻ';
$string['reviewquestionback'] = '..ͧ÷ա';
$string['reviewquestioncontinue'] = '..ͧ÷ӤӶ';
$string['sanitycheckfailed'] = 'բͼԴҴ ¡ԡ÷Ẻͺ駹';
$string['savechanges'] = 'ѹ֡¹ŧ';
$string['savechangesandeol'] = 'ѹ֡¹ŧǨ¹ٻ';
$string['savepage'] = 'ѹ֡';
$string['score'] = 'ṹ';
$string['scores'] = 'ṹ';
$string['secondpluswrong'] = 'ѧ١ͧ ͧ÷աҤ';
$string['showanunansweredpage'] = 'ʴ˹ҷѧͺ';
$string['showanunseenpage'] = 'ʴ˹ҷѧ֡';
$string['singleanswer'] = 'ӵͺ';
$string['slideshow'] = 'Ŵ';
$string['slideshowbgcolor'] = 'բͧŴ';
$string['slideshowheight'] = '٧ͧŴ';
$string['slideshowwidth'] = 'ҧͧŴ';
$string['startlesson'] = '鹺¹';
$string['studentattemptlesson'] = '$a->firstname $a->lastname Ӥ駷 $a->attempt';
$string['studentname'] = '$a ';
$string['studentoneminwarning'] = '͹ س 1 ҷ͹¡㹡÷Ӻ¹';
$string['studentoutoftime'] = '͹ 㹡÷Ӻ¹Ǥӵͺسѧҡҹաúѹ֡ṹ ҡͧ÷ӵԡ \"\"';
$string['studentresponse'] = 'ӵͺͧ$a ';
$string['submitname'] = 'ͼ';
$string['teacherjumpwarning'] = 'աҹáⴴ$a->cluster ͢$a->unseen 㹺¹ кâ˹ҵ᷹áⴴѧ ҡͧ÷ͺâ˹Ҵѧк㹰ҹйѡ¹';
$string['teacherongoingwarning'] = 'ʴṹ㹢зẺͺʴ੾йѡ¹к㹰ҹйѡ¹跴ͺ¹';
$string['teachertimerwarning'] = 'èѺҨҹ੾СѺѡ¹繡к㹰ҹйѡ¹';
$string['thatsthecorrectanswer'] = '١ͧ';
$string['thatsthewronganswer'] = 'Դ';
$string['thefollowingpagesjumptothispage'] = '˹ҶѴѧ˹ҹ';
$string['thispage'] = '˹ҹ';
$string['timed'] = 'Ѻ';
$string['timeremaining'] = '';
$string['timetaken'] = 'ҷ';
$string['topscorestitle'] = 'ṹ٧ش $a->maxhighscores ѹѺѺ¹$a->name';
$string['treeview'] = 'ͧѹ';
$string['unseenpageinbranch'] = 'ӶѧǢ͹';
$string['updatefailed'] = 'öѾഷ';
$string['updatesuccess'] = 'Ѿഷ';
$string['useeditor'] = '';
$string['usemaximum'] = '٧ش';
$string['usemean'] = '';
$string['usepassword'] = '¹ͧʼҹ㹡ҷ';
$string['viewallpages'] = 'ʴء˹';
$string['viewgrades'] = 'ʴṹ';
$string['viewhighscores'] = 'ʴ¡äṹ٧ش';
$string['viewlessonstats'] = 'ʴʶԵ';
$string['waitpostscore'] = 'سѡ袳зѧʵṹ٧ش';
$string['welldone'] = 'ҡ';
$string['whatdofirst'] = 'ͧ÷á͹';
$string['wronganswerjump'] = 'ӵͺԴ';
$string['wronganswerscore'] = 'ṹͧӵͺԴ';
$string['wrongresponse'] = 'ӵͺԴ';
$string['youhavereceived'] = 'ṹ $a->score ṹҡ $a->outof ṹѺӶ§';
$string['youhaveseen'] = 'س֡Һ¹ҡ˹˹ ͧáѺ˹ҷ ?';
$string['youmadehighscore'] = 'ҡФس $a  ѹѺṹ٧ش';
$string['youranswer'] = 'ӵͺͧس';
$string['yourcurrentgradeis'] = 'ṹ $a  ṹ';
$string['yourgradeisnow'] = 'ṹͧسѺ¹¹ $a ';
$string['yourresponse'] = 'ӵͺͧس';
$string['youshouldview'] = 'سԴҧ $a ';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/th/lesson.php <==
<?PHP // $Id$ 
      // lesson.php - created with Moodle 1.4.4 (2004083140)


$string['accesscontrol'] = 'Ǻ';
$string['actionaftercorrectanswer'] = '͵ͺӶ١';
$string['addabranchtable'] = 'úҭ';
$string['addanendofbranch'] = '˹ҨǢ';
$string['addaquestionpage'] = '˹ҤӶ';
$string['addcluster'] = '';
$string['addendofcluster'] = '˹Ҩͧ';
$string['answer'] = '͡';
$string['answeredcorrectly'] = 'ͺ١ͧ';
$string['answersfornumerical'] = 'ӵͺ繵ŢҧҵشФ٧ش';
$string['arrangebuttonshorizontally'] = 'ѴҢǹ͹ʴŴ';
$string['attempt'] = '駷 : $a';
$string['attempts'] = '';
$string['available'] = '';
$string['averagescore'] = 'ṹ';
$string['averagetime'] = '';
$string['backtreeview'] = 'Ѻѧ˹ͧѹ';
$string['branchtable'] = 'úҭ';
$string['cancel'] = '¡ԡ';
$string['canretake'] = '$a ö¹';
$string['casesensitive'] = 'Ǿ˭еǾ硶繤е';
$string['checkbranchtable'] = 'Ǩͺúҭ';
$string['checkedthisone'] = 'Ǩͺ˹ҹ';
$string['checknavigation'] = 'Ǩͺԧ';
$string['checkquestion'] = 'ǨͺӶ';
$string['classstats'] = 'ʶԵ';
$string['clicktopost'] = 'ԡ͡͡ṹͧسŧ¡äṹ٧ش';
$string['clusterjump'] = 'Ӷʴ㹺';
$string['clustertitle'] = '';
$string['comments'] = 'Դ';
$string['commentswithname'] = 'Դ繢ͧ $a->firstname {$a->lastname}';
$string['completed'] = '';
$string['confirmdeletionofthispage'] = '׹ѹź˹ҹ';
$string['congratulations'] = 'Թմ¤  س֡Ҩ¹';
$string['continue'] = '';
$string['continuetoanswer'] = '¹ӵͺ';
$string['correctanswerjump'] = 'ӵͺ١';
$string['correctanswerscore'] = 'ṹ';
$string['correctresponse'] = 'ӵͺ١';
$string['customscoring'] = 'Ѻ¹ṹ';
$string['deadline'] = 'ࢵ';
$string['deleteattempts'] = 'źѹ֡÷Ӻ¹ٻѡ¹·';
$string['deleting'] = 'ѧź';
$string['deletingpage'] = 'ź˹ $a';
$string['description'] = '͸Ժ';
$string['detailedstats'] = 'ʶԵ';
$string['didnotanswerquestion'] = 'ѧͺӶ';
$string['didnotreceivecredit'] = 'ôԵ';
$string['displayhighscores'] = 'ʴṹ٧ش';
$string['displayinleftmenu'] = 'ʴ٫';
$string['displayleftmenu'] = 'ʴ٫';
$string['displayofgrade'] = 'ʴṹ (Ѻѡ¹)';
$string['displayreview'] = 'ʴʴ';
$string['displayscorewithessays'] = 'ṹ $a->score ҡ $a->tempmaxgrade ѺӶṹѵѵ<br>$a->essayquestions 繤§աõǨṹѧ<br>кйӤṹѧѺṹѨغѹ<br><br>ṹ͹Ӷ繤§ $a->score ҡ $a->grade';
$string['displayscorewithoutessays'] = 'ṹ $a->score (ҡṹ $a->grade).';
$string['editlessonsettings'] = '䢡õ駤Һ¹ٻ';
$string['editpagecontent'] = '˹ҹ';
$string['email'] = '';
$string['emailallgradedessays'] = 'ŷء <br>ṹ§';
$string['emailgradedessays'] = 'Ťṹҡ§';
$string['emailsuccess'] = 'º';
$string['endofbranch'] = 'Ǣ';
$string['endofclustertitle'] = '';
$string['endoflesson'] = '¹ٻ';
$string['enteredthis'] = 'ç';
$string['entername'] = 'Ѻ¡äṹ٧ش';
$string['enterpassword'] = 'سʼҹ';
$string['eolstudentoutoftime'] = '͹  㹡÷Ӻ¹ٻǤӵͺѧҡҹդṹ';
$string['eolstudentoutoftimenoanswers'] = 'سѧͺӶṹ 0 Ѻ¹ٻ';
$string['essay'] = '§';
$string['essayemailsubject'] = 'ṹѺ $a Ӷ';
$string['essays'] = '§';
$string['essayscore'] = 'ṹ§';
$string['fileformat'] = 'ٻẺͧ';
$string['firstanswershould'] = 'ӵͺáѧ˹ҷͺ١';
$string['firstwrong'] = 'سṹѺ͹еͺӶ١ͧ سͧ÷Ҥӵͺ  ͤʹءʹҹ (ṹФ)';
$string['flowcontrol'] = 'Ǻҹ¹ٻ';
$string['general'] = '';
$string['gobacktolesson'] = 'Ѻѧ¹ٻ';
$string['grade'] = 'ṹ';
$string['gradeessay'] = 'ṹӶ§';
$string['gradeis'] = 'ṹ $a ';
$string['gradeoptions'] = '͡ṹ';
$string['handlingofretakes'] = 'äԴṹ¹';
$string['havenotgradedyet'] = 'ѧṹ';
$string['here'] = 'ç';
$string['highscore'] = 'ṹ٧ش';
$string['hightime'] = 'ҡش';
$string['importquestions'] = 'ҤӶ';
$string['jump'] = 'ѧ..';
$string['jumptsto'] = 'ѧ..';
$string['leftduringtimed'] = 'س͡ҡ÷Ӻ¹ٻ͹Ҩ سҤԡ \"\" ͷӺ¹ٻ';
$string['leftduringtimednoretake'] = 'س͡ҡ÷Ӻ¹ٻѺ͹حҵӺ¹ٻͷӺ¹ٻ';
$string['lesson'] = '$a ¹ٻ';
$string['lessonclosed'] = 'ҷӺ¹ٻ $a';
$string['lessondefault'] = 'ҷѺ¹繤ѧ';
$string['lessonformating'] = 'ٻẺ¹ٻ';
$string['lessonmenu'] = 'ٺ¹';
$string['lessonopen'] = 'ԴӺ¹ $a';
$string['lessonstats'] = 'ʶԵ';
$string['loginfail'] = 'к سͧա駤';
$string['lowscore'] = 'ṹش';
$string['lowtime'] = 'ҹش';
$string['mainmenu'] = 'ѡ';
$string['matchesanswer'] = 'Ѻӵͺ';
$string['maxhighscores'] = 'ӹǹṹ٧شͧʴ';
$string['maximumnumberofanswersbranches'] = 'ӹǹӵͺ/ҧ͡٧ش';
$string['maximumnumberofattempts'] = 'ӹǹ駷ͺ٧ش';
$string['maxtime'] = 'ҷ(ҷ)';
$string['maxtimewarning'] = 'س $a ҷ㹡÷Ӻ¹';
$string['minimumnumberofquestions'] = 'ӹǹӶش';
$string['modattempts'] = '͹حҵѡ¹ʴԴ';
$string['modattemptsnoteacher'] = 'ѡ¹ö੾ЧҹѺѡ¹';
$string['modulename'] = '¹ٻ';
$string['modulenameplural'] = '¹ٻ';
$string['movepagehere'] = 'ҷ';
$string['moving'] = '˹ $a';
$string['movingtonextpage'] = 'ѧӷҹ˹ҶѴ';
$string['multianswer'] = '¤ӵͺ';
$string['multipleanswer'] = 'ӵͺҡ˹';
$string['nameapproved'] = '͹حҵ';
$string['namereject'] = '¤Фسö͹س¹';
$string['nextpage'] = '˹ҵ';
$string['noanswer'] = 'դӵͺ';
$string['noattemptrecordsfound'] = '辺ѹ֡֡ ѧդṹ';
$string['nocommentyet'] = 'ѧբʹ';
$string['nohighscores'] = 'ѧդṹ٧';
$string['nooneansweredcorrectly'] = 'ѧõͺӶ١';
$string['nooneansweredthisquestion'] = 'ѧõͺӶ͹';
$string['noonecheckedthis'] = 'ѧ礢͹';
$string['nooneenteredthis'] = 'ѧҵç';
$string['noretake'] = 'سöӺ¹ٻ';
$string['normal'] = ' :: ¹¹ҧ';
$string['notcompleted'] = 'ѧó';
$string['notdefined'] = '˹';
$string['nothighscore'] = 'س $a ѹѺṹ٧ش';
$string['notitle'] = 'ժ';
$string['numberofcorrectanswers'] = 'ͺ١  $a ';
$string['numberofcorrectmatches'] = 'Ѻ١  $a ';
$string['numberofpagestoshow'] = 'ӹǹ˹ҷͧʴ';
$string['numberofpagesviewed'] = '֡  $a  ˹';
$string['ongoing'] = 'ʴṹҧӺ¹';
$string['ongoingcustom'] = '¹դṹ $a->grade ṹ ṹس $a->score ṹҡ $a->currenthigh ṹ';
$string['ongoingnormal'] = 'سͺӶ١ͧ $a->correct ͨҡ $a->viewed ';
$string['or'] = '';
$string['ordered'] = 'Ѵ§';
$string['other'] = ' ';
$string['outof'] = 'ҡ $a';
$string['outoftime'] = '';
$string['overview'] = 'Ҿ';
$string['page'] = '˹ $a ';
$string['pagecontents'] = '';
$string['pages'] = '˹';
$string['pagetitle'] = 'Ǣ';
$string['password'] = 'ʼҹ';
$string['passwordprotectedlesson'] = '¹$a ͧʼҹ㹡价';
$string['pleasecheckoneanswer'] = 'Ǩӵͺ';
$string['pleasecheckoneormoreanswers'] = 'Ǩӵͺ';
$string['pleaseenteryouranswerinthebox'] = 'سӵͺ㹪ͧҧ';
$string['pleasematchtheabovepairs'] = 'Ѻʹҹ';
$string['pointsearned'] = 'ṹ';
$string['postsuccess'] = 'ʵ';
$string['practice'] = 'ͧӺ¹ٻ';
$string['previouspage'] = '˹ҡ͹';
$string['question'] = 'Ӷ';
$string['questionoption'] = '礷ѺӶ¤ӵͺ/ ͧк¡Ǿ˭繤е';
$string['questiontype'] = 'ͧӶ';
$string['randombranch'] = '˹Ǣͷ';
$string['randompageinbranch'] = 'ӶǢ';
$string['rank'] = 'ѹѺ';
$string['reached'] = '֧';
$string['receivedcredit'] = 'ѺôԵ';
$string['redisplaypage'] = 'ʴ˹ҹա';
$string['report'] = '§ҹ';
$string['response'] = '͵ͺ͹ʴͤ..';
$string['returnmainmenu'] = 'Ѻѧѡ';
$string['returntocourse'] = 'ѺѧԪ';
$string['reviewlesson'] = 'ǡѺ¹ٻ';
$string['reviewquestionback'] = '..ͧ÷ա';
$string['reviewquestioncontinue'] = '..ͧ÷ӤӶ';
$string['sanitycheckfailed'] = 'բͼԴҴ ¡ԡ÷Ẻͺ駹';
$string['savechanges'] = 'ѹ֡¹ŧ';
$string['savechangesandeol'] = 'ѹ֡¹ŧǨ¹ٻ';
$string['savepage'] = 'ѹ֡';
$string['score'] = 'ṹ';
$string['scores'] = 'ṹ';
$string['secondpluswrong'] = 'ѧ١ͧ ͧ÷աҤ';
$string['showanunansweredpage'] = 'ʴ˹ҷѧͺ';
$string['showanunseenpage'] = 'ʴ˹ҷѧ֡';
$string['singleanswer'] = 'ӵͺ';
$string['slideshow'] = 'Ŵ';
$string['slideshowbgcolor'] = 'բͧŴ';
$string['slideshowheight'] = '٧ͧŴ';
$string['slideshowwidth'] = 'ҧͧŴ';
$string['startlesson'] = '鹺¹';
$string['studentattemptlesson'] = '$a->firstname $a->lastname Ӥ駷 $a->attempt';
$string['studentname'] = '$a ';
$string['studentoneminwarning'] = '͹ س 1 ҷ͹¡㹡÷Ӻ¹';
$string['studentoutoftime'] = '͹ 㹡÷Ӻ¹Ǥӵͺسѧҡҹաúѹ֡ṹ ҡͧ÷ӵԡ \"\"';
$string['studentresponse'] = 'ӵͺͧ$a ';
$string['submitname'] = 'ͼ';
$string['teacherjumpwarning'] = 'աҹáⴴ$a->cluster ͢$a->unseen 㹺¹ кâ˹ҵ᷹áⴴѧ ҡͧ÷ͺâ˹Ҵѧк㹰ҹйѡ¹';
$string['teacherongoingwarning'] = 'ʴṹ㹢зẺͺʴ੾йѡ¹к㹰ҹйѡ¹跴ͺ¹';
$string['teachertimerwarning'] = 'èѺҨҹ੾СѺѡ¹繡к㹰ҹйѡ¹';
$string['thatsthecorrectanswer'] = 'ӵͺ١ͧ';
$string['thatsthewronganswer'] = 'ӵͺ繤ӵͺԴ';
$string['thefollowingpagesjumptothispage'] = '˹ҶѴѧ˹ҹ';
$string['thispage'] = '˹ҹ';
$string['timed'] = 'Ѻ';
$string['timeremaining'] = '';
$string['timetaken'] = 'ҷ';
$string['topscorestitle'] = 'ṹ٧ش $a->maxhighscores ѹѺѺ¹$a->name';
$string['treeview'] = 'ͧѹ';
$string['unseenpageinbranch'] = 'ӶѧǢ͹';
$string['updatefailed'] = 'öѾഷ';
$string['updatesuccess'] = 'Ѿഷ';
$string['useeditor'] = ' HTML Editor';
$string['usemaximum'] = '٧ش';
$string['usemean'] = '';
$string['usepassword'] = '¹ͧʼҹ㹡ҷ';
$string['viewallpages'] = 'ʴء˹';
$string['viewgrades'] = 'ʴṹ';
$string['viewhighscores'] = 'ʴ¡äṹ٧ش';
$string['viewlessonstats'] = 'ʴʶԵ';
$string['waitpostscore'] = 'سѡ袳зѧʵṹ٧ش';
$string['welldone'] = 'ҡ';
$string['whatdofirst'] = 'ͧ÷á͹';
$string['wronganswerjump'] = '͵ͺԴѧ';
$string['wronganswerscore'] = 'ṹͧӵͺԴ';
$string['wrongresponse'] = 'ӵͺԴ';
$string['youhavereceived'] = 'ṹ $a->score ṹҡ $a->outof ṹѺӶ§';
$string['youhaveseen'] = 'س֡Һ¹ҡ˹˹ ͧáѺ˹ҷ ?';
$string['youmadehighscore'] = 'ҡФس $a  ѹѺṹ٧ش';
$string['youranswer'] = 'ӵͺͧس';
$string['yourcurrentgradeis'] = 'ṹ $a  ṹ';
$string['yourgradeisnow'] = 'ṹͧسѺ¹¹ $a ';
$string['yourresponse'] = 'ӵͺͧس';
$string['youshouldview'] = 'سԴҧ $a ˹';

?>
